**Purpose**: pyLoad-ng is a Free and Open Source download manager written in Python and designed to be extremely lightweight, easily extensible and fully manageable via web.

[Detailed LinuxServer.io Deployment Info](https://docs.linuxserver.io/images/docker-pyload-ng/)


## Docker Configuration
```jsx title="docker-compose.yml"
---
services:
  pyload-ng:
    image: lscr.io/linuxserver/pyload-ng:latest
    container_name: pyload-ng
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=America/Denver # (1)
    volumes:
      - /srv/containers/pyload-ng/config:/config
      - smb-share:/downloads
    ports:
      - 8000:8000
      - 9666:9666  # (2)
    restart: unless-stopped
    networks:
        docker_network:
          ipv4_address: 192.168.5.30

volumes:
  smb-share:
    driver: local
    driver_opts:
      type: cifs
      o: username=nicole.rappe,password=REDACTED,domain=BUNNY-LAB,vers=3.0 # (3)
      device: "//192.168.3.3/Downloads" # (4)

networks:
  docker_network:
    external: true
```
    
    1.  Set this to your own timezone.
    2.  This is optional.  Additional documentation needed to convey what this port is used for.  Possibly API access.
    3.  This assumes you want your download folder to be a SMB network share, this section allows you to connect to the share so Pyload can download content directly into the network folder.  Replace the username and `REDACTED` password with your actual credentials.  Remove the `domain` argument if the SMB server is not domain-joined.
    4.  This is the destination network share to target with the given credentials in section 3.

```jsx title=".env"
N/A
```

## Traefik Reverse Proxy Configuration
If the container does not run on the same host as Traefik, you will need to manually add configuration to Traefik's dynamic config file, outlined below.
``` yaml
http:
  routers:
    pyload:
      entryPoints:
        - websecure
      tls:
        certResolver: letsencrypt
      http2:
      service: pyload
      rule: Host(`pyload.bunny-lab.io`)

  services:
    pyload:
      loadBalancer:
        servers:
          - url: http://192.168.5.30:8000
        passHostHeader: true
```

!!! warning "Change Default Admin Credentials"
    Pyload ships with the username `pyload` and password `pyload`.  Make sure you change the credentials immediately after initial login.
    Navigate to "**Settings > Users > Pyload:"Change Password"**"